@@ -293,7 +293,7 @@ elseif (isset($_REQUEST['view'])) {
 		$blog->user_id = $me['user_id'];
 		
 		$output_blogs = $blog->selBlogs();
-		echo "HH";
+		
 		$menu_section = "my";
 	}
 	elseif ($_REQUEST['view'] == "marked_blogs" && isset($me['user_id'])) {
@@ -393,13 +393,10 @@ if (!empty($output_blog)) {
 				$allow_view = 1;
 				break;
 			}
-			elseif (!empty($_SESSION['s_md5']) && $i['level_id'] == $c_node['rsp']['rsp_level']['node']) { // is the item set to node and the user logged in?
+			elseif (!empty($_SESSION['s_md5']) && empty($i['degree_id']) && $i['level_id'] == $c_node['rsp']['rsp_level']['node']) { // is the item set to node and the user logged in?
 				$allow_view = 1;
 				break;
 			}
-			elseif ($i['level_id'] == $c_node['rsp']['rsp_level']['degree'] && empty($i['degree_id'])) { // is it set to network (everyone)?
-				$allow_view = 1;
-			}
 			elseif (!empty($i['degree_id'])) { // is it set to network and are they in my network?
 				foreach($_SESSION['relations'] as $key => $r):
 					if ($output_blog['user_id'] == $r['user_id_relation']) {
@@ -477,7 +474,11 @@ if (!empty($output_blog)) {
 	
 	// GET AUTHOR
 	if (!empty($output_blog['group_id'])) {
-		$output_author = $user->selProfile($output_group['member']['profile_id'], null);
+		$output_group['author'] = $group->getGroupMembership($output_blog['user_id']);
+		
+		if (!empty($output_group['author']['profile_id'])) {
+			$output_author = $user->selProfile($output_group['author']['profile_id'], null);
+		}
 	}
 	else {
 		$output_author = $user->selProfile(null, $output_blog['user_id']);
@@ -623,7 +624,8 @@ if (!empty($output_blog)) {
 	$template_pageLinkNote = $output_blog['blog_title'];
 }
 
-$body->set('batch_enabled', $c_node['batch']['enabled']); 
+$body->set('batch_enabled', $c_node['batch']['enabled']);
+$body->set('rspconfig', $c_node['rsp']);
 
 $template_pageLink = $lang['txt_blog'];
 
